@@ -283,8 +283,13 @@ class DynamicSetting(object):
 
         if not self.download_subkey is None:
             if not isinstance(data, dict) or not self.download_subkey in data:
-                self.logger.error(f'Response from url should be a JSON object containing the key {self.download_subkey}',
-                                  data=self.log_data)
+                if self.fallback_allowed or not self.health_relevant:
+                    self.logger.warning(
+                        f'Response from url should be a JSON object containing the key {self.download_subkey}',
+                        data=self.log_data)
+                else:
+                    self.logger.error(f'Response from url should be a JSON object containing the key {self.download_subkey}',
+                                      data=self.log_data)
                 return None, None
             data = data[self.download_subkey]
 
@@ -533,7 +538,7 @@ class DynamicSetting(object):
             'slug': self.slug,
             'load_time': self.load_time.isoformat(),
             'download_time': download_time_iso,
-            'age': str(self.age),
+            'age': str(self.age) if not self.age is None else None,
             'max_age': str(self.max_age),
             'allow_fallback': self.fallback_allowed,
             'fallback': self.is_fallback,
